@@ -24,10 +24,11 @@ import inspect
 from sprox.util import name2label, is_widget, is_widget_class
 
 from sprox.widgets import SproxMethodPutHiddenField, CalendarDatePicker, CalendarDateTimePicker
-from viewbase import ViewBase, ViewBaseError
+from .viewbase import ViewBase, ViewBaseError
 from formencode import Schema, All
 from formencode import Validator
-from formencode.validators import UnicodeString, String
+from formencode.validators import String
+from sprox.validators import UnicodeString
 
 from sprox.validators import UniqueValue
 from sprox.metadata import FieldsMetadata
@@ -120,12 +121,12 @@ class FormBase(ViewBase):
     >>>
     >>> town_form = UserOnlyTownForm(session)
     >>>
-    >>> print town_form() # doctest: +XML
+    >>> print(town_form()) # doctest: +XML
     <form enctype="multipart/form-data" method="post">
          <span class="error"></span>
         <table >
         <tr class="odd"  id="sx_town:container">
-            <th>Town</th>
+            <th><label for="sx_town">Town</label></th>
             <td >
                 <select name="town" id="sx_town">
              <option value="1">Arvada</option>
@@ -279,7 +280,7 @@ class FormBase(ViewBase):
         fields = super(FormBase, self)._do_get_fields()
         provider = self.__provider__
         field_order = self.__field_order__ or []
-        add_fields = self.__add_fields__.keys()
+        add_fields = list(self.__add_fields__.keys())
         for relation in provider.get_relations(self.__entity__):
             # do not remove field if it is listed in field_order
             for rel in provider.relation_fields(self.__entity__, relation):
@@ -299,7 +300,7 @@ class FormBase(ViewBase):
         """
         v_type = self.__field_validator_types__.get(field_name, self.__validator_selector__[field])
         if field_name in self.__require_fields__ and v_type is None:
-            v_type = String
+            v_type = UnicodeString
         if v_type is None:
             return
         args = self._do_get_validator_args(field_name, field, v_type)
@@ -356,7 +357,8 @@ class EditableForm(FormBase):
 
     def _do_get_field_widgets(self, fields):
         widgets = super(EditableForm, self)._do_get_field_widgets(fields)
-        widgets['_method'] = SproxMethodPutHiddenField(id='sprox_method', validator=String(if_missing=None))
+        widgets['_method'] = SproxMethodPutHiddenField(id='sprox_method',
+                                                       validator=UnicodeString(if_missing=None))
         return widgets
 
     __check_if_unique__ = False
@@ -394,40 +396,40 @@ class AddRecordForm(FormBase):
     ...     display_name           = TextField
     ...     verify_password        = PasswordField('verify_password')
     >>> registration_form = RegistrationForm()
-    >>> print registration_form() # doctest: +XML
+    >>> print(registration_form()) # doctest: +XML
     <form enctype="multipart/form-data" method="post">
          <span class="error"></span>
         <table >
-        <tr class="odd"  id="sx_user_name:container">
-            <th>User Name</th>
+        <tr class="odd required"  id="sx_user_name:container">
+            <th><label for="sx_user_name">User Name</label></th>
             <td >
                 <input name="user_name" type="text" id="sx_user_name" value=""/>
                 <span id="sx_user_name:error"></span>
             </td>
         </tr>
-        <tr class="even"  id="sx_email_address:container">
-            <th>Email Address</th>
+        <tr class="even required"  id="sx_email_address:container">
+            <th><label for="sx_email_address">Email Address</label></th>
             <td >
                 <input name="email_address" type="text" id="sx_email_address"/>
                 <span id="sx_email_address:error"></span>
             </td>
         </tr>
         <tr class="odd"  id="sx_display_name:container">
-            <th>Display Name</th>
+            <th><label for="sx_display_name">Display Name</label></th>
             <td >
                 <input name="display_name" type="text" id="sx_display_name" value=""/>
                 <span id="sx_display_name:error"></span>
             </td>
         </tr>
-        <tr class="even"  id="sx_password:container">
-            <th>Password</th>
+        <tr class="even required"  id="sx_password:container">
+            <th><label for="sx_password">Password</label></th>
             <td >
                 <input type="password" name="password" id="sx_password"/>
                 <span id="sx_password:error"></span>
             </td>
         </tr>
         <tr class="odd"  id="verify_password:container">
-            <th>Verify Password</th>
+            <th><label for="verify_password">Verify Password</label></th>
             <td >
                 <input type="password" name="verify_password" id="verify_password"/>
                 <span id="verify_password:error"></span>
@@ -451,7 +453,7 @@ class AddRecordForm(FormBase):
     ...     __entity__ = User
     ...     __limit_fields__ = ['user_name']
     >>> user_form = AddUserForm(session)
-    >>> user_form.validate(params={'sprox_id':'asdf', 'user_name':u'asdf'}) # doctest: +SKIP
+    >>> user_form.validate(params={'sprox_id':'asdf', 'user_name':'asdf'}) # doctest: +SKIP
     Traceback (most recent call last):
     ...
     Invalid: user_name: That value already exists
@@ -491,19 +493,19 @@ class DisabledForm(FormBase):
     ...     __model__ = User
     ...     __limit_fields__ = ['user_name', 'email_address']
     >>> disabled_user_form = DisabledUserForm()
-    >>> print disabled_user_form(values=dict(user_name='percious', email='chris@percious.com'))  # doctest: +XML
+    >>> print(disabled_user_form(values=dict(user_name='percious', email='chris@percious.com')))  # doctest: +XML
     <form enctype="multipart/form-data" method="post">
          <span class="error"></span>
         <table >
         <tr class="odd"  id="sx_user_name:container">
-            <th>User Name</th>
+            <th><label for="sx_user_name">User Name</label></th>
             <td >
                 <input name="user_name" value="" disabled="disabled" type="text" id="sx_user_name"/>
                 <span id="sx_user_name:error"></span>
             </td>
         </tr>
         <tr class="even"  id="sx_email_address:container">
-            <th>Email Address</th>
+            <th><label for="sx_email_address">Email Address</label></th>
             <td >
                 <textarea disabled="disabled" name="email_address" id="sx_email_address"></textarea>
                 <span id="sx_email_address:error"></span>
